@@ -2,28 +2,6 @@
 fields <- c("Package","Maintainer","Author","Version",
             "License","Title","Description")
 
-`inlinedocExample<-` <- structure(function
-### Attach example code to attribute 'ex'.
-(f,
-### the function, to which to attach code for section 'examples' in
-### documentation
- value
-### the example code, usually the body of a function (see example)
-) {
-	## see parsers.R examples.in.attr
-	attr (f, "ex") <- value
-	f
-},ex=function(){
-	### Simple Hello-World function.
-	helloWorld <- function(){ cat('Hello World!\n')}
-	inlinedocExample(helloWorld) <- function(){
-		# all text including comments inside this block 
-		# will go to the examples section of 
-		# function helloWorld
-		helloWorld()	# prints Hello World
-	}	
-})
-		
 ### Default DESCRIPTION, written if it doesn't exist.  TODO, PhG:
 ### start with reasonable values here!
 empty.description <- matrix("",ncol=length(fields),dimnames=list(NULL,fields))
@@ -424,6 +402,8 @@ modify.Rd.file <- function
   m <- regexpr("usage[{][^}]*[}]",txt)
   Mend <- m+attr(m,"match.length")
   utxt <- substr(txt,m,Mend)
+  ## multiple lines for the PDF!
+  utxt <- gsub(", ",",\n",utxt)
   if(length(grep("usage[{]data",utxt))){
      utxt <- gsub("data[(]([^)]*)[)]","\\1",utxt)
    }
